@@ -39,17 +39,12 @@ struct NtpServer {
 	{ "time.nrc.ca", "Canada" },
 	{ "ntp1.cmc.ec.gc.ca", "Eastern Canada" },
 	{ "ntp2.cmc.ec.gc.ca", "Eastern Canada" },
-	{ "clock.tricity.wsu.edu", "Washington, USA" },
 	{ "wuarchive.wustl.edu", "Missouri, USA" },
 	{ "clock.psu.edu", "Pennsylvania, USA" },
-	{ "constellation.ecn.uoknor.edu", "Oklahoma, USA" },
 	{ "gilbreth.ecn.purdue.edu", "Indiana, USA" },
 	{ "molecule.ecn.purdue.edu", "Indiana, USA" },
-	{ "libra.rice.edu", "Texas, USA" },
-	{ "ntp.cox.smu.edu", "Texas, USA" },
 	{ "ntp.tmc.edu", "Texas, USA" },
 	{ "louie.udel.edu", "Delaware, USA" },
-	{ "ntp.cmr.gov", "Virginia, USA" },
 	{ "ntp0.cornell.edu", "New York, USA" },
 	{ "ntp-0.cso.uiuc.edu", "Illinois, USA" },
 	{ "ntp1.cs.wisc.edu", "Wisconsin, USA" },
@@ -64,15 +59,10 @@ struct NtpServer {
 	{ "fartein.ifi.uio.no", "Norway, Europe" },
 	{ "ntp1.arnes.si", "Slovenia, Europe" },
 	{ "ntp2.arnes.si", "Slovenia, Europe" },
-	{ "ntp.landau.ac.ru", "Moscow, Russia" },
 	{ "time.esec.com.au", "Australia" },
 	{ "ntp.adelaide.edu.au", "South Australia" },
-	{ "ntp.shim.org", "Singapore, Asia" },
 	{ "time.nuri.net", "Korea, Asia" },
 	{ "ntp.cs.mu.oz.au", "Melbourne, Australia" },
-	{ "ntp.mel.nml.csiro.au", "Melbourne, Australia" },
-	{ "ntp.nml.csiro.au", "Sydney, Australia" },
-	{ "ntp.per.nml.csiro.au", "Perth, Australia" },
 	{ "swisstime.ethz.ch", "Zurich, Switzerland" },
 	{ "ntp.cesnet.cz", "Prague, Czech Republic" },
 	{ "ntpa2.kph.uni-mainz.de", "Mainz, Germany" },
@@ -95,6 +85,7 @@ struct NtpServer {
 	{ "time1.stupi.se", "Stockholm, Sweden" },
 	{ "goodtime.ijs.si", "Ljubljana, Slovenia" },
 	{ "ntp2.ja.net", "United Kingdom" },
+	{ "laikas.pfi.lt", "Lithuania" },
 	{ NULL }
 };
 
@@ -189,10 +180,7 @@ on_server_toggled (GtkCellRendererToggle *renderer,
 	GtkListStore *store = (GtkListStore *) data;
 	GtkTreePath *path  = gtk_tree_path_new_from_string (path_str);
 	GstTimeTool *tool;
-	OobsList *list;
-	OobsListIter *list_iter;
 	GtkTreeIter iter;
-	gchar *url;
 
 	if (!gtk_tree_model_get_iter (GTK_TREE_MODEL (store), &iter, path)) {
 		g_critical ("could not get list iter");
@@ -296,7 +284,6 @@ on_ntp_addserver (GtkWidget *widget, GstDialog *dialog)
 {
 	GtkEditable *ntp_entry;
 	GtkTreeView *ntp_list;
-	GtkWidget *item;
 	GtkListStore *store;
 	GtkTreeIter iter;
 	gchar *text;
