@@ -48,13 +48,16 @@ struct GroupTreeItem_
 	GroupTreeItem *children;
 };
 
-void    groups_table_clear              (void);
-void	create_groups_table		(void);
-void	populate_groups_table		(void);
-void	group_table_update_content	(void);
+void          groups_table_clear               (void);
+void	      create_groups_table              (void);
+void          populate_groups_table            (void);
+void	      group_table_update_content       (void);
 
-void    groups_table_set_group          (OobsGroup    *group,
-                                         GtkTreeIter  *iter);
-void    groups_table_add_group          (OobsGroup    *group);
+GtkTreeModel *groups_table_get_model           ();
+void          groups_table_set_group           (OobsGroup    *group,
+                                                GtkTreeIter  *iter);
+void          groups_table_add_group           (OobsGroup    *group);
+
+GList        *groups_table_get_row_references  ();
 
 #endif /* _GROUPS_TABLE_H */
